
#ifndef _STDIO_H
#include <stdio.h>
#ifndef _STDIO_H
#define _STDIO_H
#endif
#endif

#ifndef _MATH_H
#include <math.h>
#ifndef _MATH_H
#define _MATH_H
#endif
#endif

#ifndef _LALSTDLIB_H
#include "LALStdlib.h"
#ifndef _LALSTDLIB_H
#define _LALSTDLIB_H
#endif
#endif

#ifndef _AVFACTORIES_H
#include "AVFactories.h"
#ifndef _AVFACTORIES_H
#define _AVFACTORIES_H
#endif
#endif

#ifndef _FRAMEDATA_H
#include "FrameData.h"
#ifndef _FRAMEDATA_H
#define _FRAMEDATA_H
#endif
#endif

const int debuglevel = 3;

int
main ()
{
  const INT4 numPoints = 65536;
  const INT4 numSegs   = 10;

  Status status;

  FrameDataPar *framepar = NULL;
  FrameDataOut  frameout;
  FrameDataInp  frameinp;

  INT2TimeSeries           framedata;
  COMPLEX8FrequencySeries  response;

  FILE *fp;
  char  fname[256];

  INT4 seg;
  INT4 i;

  framedata.data = NULL;
  I2CreateVector (&status, &framedata.data, numPoints);

  response.data = NULL;
  CCreateVector (&status, &response.data, numPoints);

  InitializeFrameData (&status, &framepar);

  frameout.framedata = &framedata;

  for (seg = 0; seg < numSegs; ++seg)
  {

    /* get next segment of locked data */
    frameout.newLock = 0;
    do
    {
      while (frameout.newLock)
      {
        frameinp.seek = 1;
        frameinp.seekPoints = 3*60/framedata.deltaT; /* 3 minutes */
        GetFrameData (&status, &frameout, &frameinp, framepar);
        if (status.statusCode)
          goto exit;
      }

      frameinp.seek = 0;
      frameinp.seekPoints = 0;
      GetFrameData (&status, &frameout, &frameinp, framepar);
      if (status.statusCode)
        goto exit;
    }
    while (frameout.newLock);

    if (frameout.newCal) {
      CalibrateFrameData (&status, &response, framepar);

      /* print calibration info */
      if (1)
      {
        sprintf (fname, "Response.%03d", seg);
        fp = fopen (fname, "w");

        for (i = 0; i < response.data->length; ++i)
        {
          REAL4 re  = response.data->data[i].re;
          REAL4 im  = response.data->data[i].im;
          REAL4 mod = sqrt (re*re + im*im);
          REAL4 arg = atan2 (im, re);
          fprintf (fp, "%u\t%e\t%e\n", i, mod, arg);
        }

        fclose (fp);
      }

    }


    /* print data vector */
    if (0)
    {
      sprintf (fname, "Segment.%03d", seg);
      fp = fopen (fname, "w");

      for (i = 0; i < framedata.data->length; ++i)
        fprintf (fp, "%u\t%d\n", i, framedata.data->data[i]);

      fclose (fp);
    }

  }


exit:

  FinalizeFrameData (&status, &framepar);
  I2DestroyVector (&status, &framedata.data);
  CDestroyVector (&status, &response.data);

  LALCheckMemoryLeaks ();

  return 0;
}
